
use strict;
use warnings;
use Test::More tests => 1;
use Test::Exception;
use Test::Differences;

use Data::Dumper;
use Path::Class;
use File::Path;



use lib "lib";
use_ok("File::Corresponding");




__END__
